@@ -2,6 +2,7 @@ from typing import List
 
 from metaphor.models.metadata_change_event import DataPlatform, MetadataChangeEvent
 
+from metaphor.common.entity_id import dataset_fullname
 from metaphor.common.event_util import EventUtil
 from metaphor.common.logger import get_logger
 from metaphor.postgresql.extractor import PostgreSQLExtractor
@@ -53,7 +54,7 @@ class RedshiftExtractor(PostgreSQLExtractor):
         )
 
         for result in results:
-            full_name = self._dataset_name(catalog, result["schema"], result["table"])
+            full_name = dataset_fullname(catalog, result["schema"], result["table"])
             if full_name not in self._datasets:
                 logger.warning(f"table {full_name} not found")
                 continue
