@@ -1,4 +1,5 @@
 import base64
+import json
 import re
 import traceback
 from typing import Dict, List, Optional, Tuple
@@ -45,7 +46,8 @@ class TableauExtractor(BaseExtractor):
         self._base_url: Optional[str] = None
         self._views: Dict[str, ViewItem] = {}
         self._dashboards: Dict[str, Dashboard] = {}
-        self._snowflake_account = None
+        self._snowflake_account: Optional[str] = None
+        self._bigquery_project_name_to_id_map: Dict[str, str] = dict()
 
     @staticmethod
     def config_class():
@@ -57,6 +59,7 @@ class TableauExtractor(BaseExtractor):
         logger.info("Fetching metadata from Tableau")
 
         self._snowflake_account = config.snowflake_account
+        self._bigquery_project_name_to_id_map = config.bigquery_project_name_to_id_map
 
         assert (
             config.access_token or config.user_password
@@ -79,21 +82,24 @@ class TableauExtractor(BaseExtractor):
 
         with server.auth.sign_in(tableau_auth):
             # fetch all views, with preview image
-            views: List[ViewItem] = [item for item in Pager(server.views, usage=True)]
+            views: List[ViewItem] = list(Pager(server.views, usage=True))
             logger.info(
                 f"There are {len(views)} views on site: {[view.name for view in views]}\n"
             )
             for item in views:
-                server.views.populate_preview_image(item)
+                logger.debug(json.dumps(item.__dict__, default=str))
+                if not config.disable_preview_image:
+                    server.views.populate_preview_image(item)
                 self._views[item.id] = item
 
             # fetch all workbooks
-            workbooks: List[WorkbookItem] = [item for item in Pager(server.workbooks)]
+            workbooks: List[WorkbookItem] = list(Pager(server.workbooks))
             logger.info(
                 f"\nThere are {len(workbooks)} work books on site: {[workbook.name for workbook in workbooks]}"
             )
             for item in workbooks:
                 server.workbooks.populate_views(item, usage=True)
+                logger.debug(json.dumps(item.__dict__, default=str))
 
                 try:
                     self._parse_dashboard(item)
@@ -151,17 +157,22 @@ class TableauExtractor(BaseExtractor):
         upstream_datasets = [
             self._parse_dataset_id(table) for table in workbook["upstreamTables"]
         ]
-        source_datasets = [
-            str(dataset_id)
-            for dataset_id in upstream_datasets
-            if dataset_id is not None
-        ]
+        source_datasets = list(
+            set(
+                [
+                    str(dataset_id)
+                    for dataset_id in upstream_datasets
+                    if dataset_id is not None
+                ]
+            )
+        )
 
         if source_datasets:
             dashboard.upstream = DashboardUpstream(source_datasets=source_datasets)
 
     def _parse_dataset_id(self, table: Dict) -> Optional[EntityId]:
         table_name = table["name"]
+        table_fullname = table["fullName"]
         table_schema = table["schema"]
         database_name = table["database"]["name"]
 
@@ -175,17 +186,41 @@ class TableauExtractor(BaseExtractor):
 
         platform = connection_type_map[connection_type]
 
-        if "." in table_name:
-            fullname = f"{database_name}.{table_name}"
+        # if table fullname contains three segments, use it as dataset name
+        if table_fullname.count(".") == 2:
+            fullname = table_fullname
         else:
-            fullname = f"{database_name}.{table_schema}.{table_name}"
+            # use BigQuery project ID to replace project name, to be consistent with the BigQuery crawler
+            if platform == DataPlatform.BIGQUERY:
+                if database_name in self._bigquery_project_name_to_id_map:
+                    database_name = self._bigquery_project_name_to_id_map[database_name]
+                else:
+                    # use project name as database name, may not match with BigQuery crawler
+                    logger.warning(
+                        f"BigQuery project name {database_name} not defined in config 'bigquery_project_name_to_id_map'"
+                    )
+
+            # if table name has two segments, then it contains "schema" and "table_name"
+            if "." in table_name:
+                fullname = f"{database_name}.{table_name}"
+            else:
+                fullname = f"{database_name}.{table_schema}.{table_name}"
+
+        fullname = (
+            fullname.replace("[", "")
+            .replace("]", "")
+            .replace("`", "")
+            .replace("'", "")
+            .replace('"', "")
+            .lower()
+        )
 
         account = (
             self._snowflake_account if platform == DataPlatform.SNOWFLAKE else None
         )
 
-        logger.info(f"dataset id: {fullname} {connection_type} {account}")
-        return to_dataset_entity_id(fullname.lower(), platform, account)
+        logger.debug(f"dataset id: {fullname} {connection_type} {account}")
+        return to_dataset_entity_id(fullname, platform, account)
 
     def _parse_chart(self, view: ViewItem) -> Chart:
         # encode preview image raw bytes into data URL
@@ -198,7 +233,7 @@ class TableauExtractor(BaseExtractor):
             )
         except Exception as error:
             logger.error(
-                f"failed to fetch preview for chart {view.name}, error {error}"
+                f"Failed to build preview data URL for {view.name}, error {error}"
             )
 
         view_url = self._build_view_url(view.content_url)
